-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

---------------------
-- Prep the module --
---------------------
local M = {}
M.type = "auxilliary"
M.relevantDevice = nil
M.defaultOrder = 11000



-----------------
-- Debug stuff --
-----------------
local ugfxCalled = 0



---------------------
-- State variables --
---------------------

-- Old onChange values
local oldOnChangeValue = 0
local oldOnChangeCtrValue = 0

-- Elapsed time
local timeElapsed = 0
local timeLimit = 0.01



---------------------------------------------
-- Graphics update function                --
-- Updates other stuff too according to dt --
---------------------------------------------
local function updateGFX(dt)
	
	-- Regular intervals
	timeElapsed = timeElapsed + dt
	if timeElapsed < timeLimit then return end
	timeElapsed = 0
	
	-- Check onDown event
	local onDownEvent = (electrics.values['onDownEvent'] or 0)
	if onDownEvent == 1 then
		electrics.values['onDownEvent'] = 0
		gui.message("onDown event detected")
	end
	
	-- Check onUp event
	local onUpEvent = (electrics.values['onUpEvent'] or 0)
	if onUpEvent == 1 then
		electrics.values['onUpEvent'] = 0
		gui.message("onUp event detected")
	end
	
	-- Check centered onChange event
	local onChangeCtrValue = (electrics.values['onChangeCtrEvent'] or 0)
	if oldOnChangeCtrValue ~= onChangeCtrValue then
		oldOnChangeCtrValue = onChangeCtrValue
		gui.message("Centered onChange event detected: VALUE = " .. tostring(onChangeCtrValue))
	end
	
	-- Check uncentered onChange event
	local onChangeValue = (electrics.values['onChangeEvent'] or 0)
	if oldOnChangeValue ~= onChangeValue then
		oldOnChangeValue = onChangeValue
		gui.message("Uncentered onChange event detected: VALUE = " .. tostring(onChangeValue))
	end
	
	-- Debug message
	if ugfxCalled == 0 then
		ugfxCalled = 1
		print("Control Cone updateGFX called")
	end
end



-- Reset what we need to
local function reset()
	oldOnChangeValue = 0
	oldOnChangeCtrValue = 0
	timeElapsed = 0
	electrics.values['onDownEvent'] = 0
	electrics.values['onUpEvent'] = 0
	electrics.values['onChangeEvent'] = 0
	electrics.values['onChangeCtrEvent'] = 0
end



-- Initialize everything
local function init(jbeamdata)
	electrics.values['onDownEvent'] = 0
	electrics.values['onUpEvent'] = 0
	electrics.values['onChangeEvent'] = 0
	electrics.values['onChangeCtrEvent'] = 0
end



-- Public interface
M.init = init
M.reset = reset
M.updateGFX = updateGFX

-- Return the module
return M
